@@ -27,7 +27,7 @@ public class DeskewTests : ContextualTests
         var image = LoadImage(ImageResources.skewed);
         var transform = Deskewer.GetDeskewTransform(image);
         var deskewedImage = image.PerformTransform(transform);
-        ImageAsserts.Similar(ImageResources.deskewed, deskewedImage, ImageAsserts.XPLAT_RMSE_THRESHOLD);
+        ImageAsserts.Similar(ImageResources.deskewed, deskewedImage, ImageAsserts.XL_RMSE_THRESHOLD);
     }
 
     [Fact]
