@@ -9,6 +9,9 @@ public enum PlatformFlags
     Linux = 4,
     X64 = 8,
     Arm64 = 16,
-    ImageSharp = 32,
-    Wpf = 64
+    ImageSharpImage = 32,
+    WpfImage = 64,
+    GdiImage = 128,
+    GtkImage = 256,
+    MacImage = 512
 }
\ No newline at end of file
