@@ -55,26 +55,28 @@ public static class MsixPackager
         mappingFile.WriteLine($"\"{resourcesPriPath}\" \"resources.pri\"");
         mappingFile.Close();
 
-        var makePri = @"C:\Program Files (x86)\Windows Kits\10\bin\10.0.19041.0\x64\makepri.exe";
+        var makePri = @"C:\Program Files (x86)\Windows Kits\10\bin\10.0.22621.0\x64\makepri.exe";
         var makeAppx = @"C:\Program Files (x86)\Windows Kits\10\App Certification Kit\makeappx.exe";
 
         if (File.Exists(resourcesPriPath)) File.Delete(resourcesPriPath);
         Cli.Run(makePri,
             $"new /pr \"{msixConfig}\" /cf \"{msixConfig}\\priconfig.xml\" /o /of \"{resourcesPriPath}\" /mn \"{manifestPath}\"");
 
-        Cli.Run(makeAppx, $"pack /f \"{mappingFilePath}\" /p \"{msixStorePath}\"");
-
         File.WriteAllText(manifestPath, File.ReadAllText(manifestPath)
             .Replace(
                 "Version=\"1.0.0.0\"",
                 $"Version=\"{pkgInfo.VersionNumber}.0\"")
-            .Replace(
-                "CN=1D624E39-8523-4AAC-B3B6-1452E653A003",
-                N2Config.WindowsIdentity)
             .Replace(
                 "<Resource Language=\"en-us\" />",
                 GetSupportedLanguages(pkgInfo)));
 
+        Cli.Run(makeAppx, $"pack /f \"{mappingFilePath}\" /p \"{msixStorePath}\"");
+
+        File.WriteAllText(manifestPath, File.ReadAllText(manifestPath)
+            .Replace(
+                "CN=1D624E39-8523-4AAC-B3B6-1452E653A003",
+                N2Config.WindowsIdentity));
+
         Cli.Run(makeAppx, $"pack /f \"{mappingFilePath}\" /p \"{msixPath}\"");
 
         if (!noSign)
