@@ -70,13 +70,10 @@ public class PackageCommand : ICommand<PackageOptions>
             PopulatePackageInfo(buildPath, platform, pkgInfo);
         }
 
-        if (platform == Platform.Win64)
-        {
-            // No need for a 32-bit worker on ARM64
-            var workerPath = Path.Combine(Paths.SolutionRoot, "NAPS2.App.Worker", "bin", "Release", "net9-windows",
-                "win-x86", "publish");
-            pkgInfo.AddFile(new PackageFile(workerPath, "lib", "NAPS2.Worker.exe"));
-        }
+        // Include the 32-bit worker (on both x64 and arm64) for TWAIN support
+        var workerPath = Path.Combine(Paths.SolutionRoot, "NAPS2.App.Worker", "bin", "Release", "net9-windows",
+            "win-x86", "publish");
+        pkgInfo.AddFile(new PackageFile(workerPath, "lib", "NAPS2.Worker.exe"));
 
         var appBuildPath = Path.Combine(Paths.SolutionRoot, "NAPS2.App.WinForms", "bin", "Release", "net9-windows",
             arch, "publish");
@@ -85,24 +82,10 @@ public class PackageCommand : ICommand<PackageOptions>
             AddPlatformFiles(pkgInfo, appBuildPath, "_win64");
             // Special case as we have a 64 bit main app and a 32 bit worker
             AddPlatformFile(pkgInfo, appBuildPath, "_win32", "twaindsm.dll");
-
-            // Include VC++ redistributable files for Tesseract so the user doesn't need to install them separately
-            var vcRedistPath = Path.Combine(Paths.SolutionRoot, "NAPS2.Setup", "lib", "win64", "vcredist");
-            foreach (var file in new DirectoryInfo(vcRedistPath).EnumerateFiles())
-            {
-                pkgInfo.AddFile(new PackageFile(file.DirectoryName!, Path.Combine("lib", "_win64"), file.Name));
-            }
         }
         if (platform == Platform.WinArm64)
         {
             AddPlatformFiles(pkgInfo, appBuildPath, "_winarm");
-
-            // Include VC++ redistributable files for Tesseract so the user doesn't need to install them separately
-            var vcRedistPath = Path.Combine(Paths.SolutionRoot, "NAPS2.Setup", "lib", "winarm", "vcredist");
-            foreach (var file in new DirectoryInfo(vcRedistPath).EnumerateFiles())
-            {
-                pkgInfo.AddFile(new PackageFile(file.DirectoryName!, Path.Combine("lib", "_winarm"), file.Name));
-            }
         }
 
         pkgInfo.AddFile(new PackageFile(appBuildPath, "", "appsettings.xml"));
